@@ -10,10 +10,10 @@ async def test_load_windows_domain(mock_hub, hub):
     )
 
     with mock.patch("shutil.which", return_value=True):
-        mock_hub.grains.net.realm.load_windows_domain = (
-            hub.grains.net.realm.load_windows_domain
+        mock_hub.grains.bsd.net.realm.load_windows_domain = (
+            hub.grains.bsd.net.realm.load_windows_domain
         )
-        await mock_hub.grains.net.realm.load_windows_domain()
+        await mock_hub.grains.bsd.net.realm.load_windows_domain()
 
     assert mock_hub.grains.GRAINS.windowsdomain == "TESTDOMAIN"
     assert mock_hub.grains.GRAINS.windowsdomaintype == "Domain"
